@@ -6,7 +6,8 @@ import datetime
 import mock
 
 from sentry.interfaces import Interface
-from sentry.models import Event, Group, Project
+from sentry.models import Event, Group, Project, MessageCountByMinute, ProjectCountByMinute, \
+  FilterValue, MessageFilterValue
 
 from tests.base import TestCase
 
@@ -38,6 +39,7 @@ class SentryManagerTest(TestCase):
 
     def test_valid_only_message(self):
         event = Group.objects.from_kwargs(1, message='foo')
+        self.assertEquals(event.group.last_seen, event.datetime)
         self.assertEquals(event.message, 'foo')
         self.assertEquals(event.project_id, 1)
 
@@ -59,48 +61,6 @@ class SentryManagerTest(TestCase):
             self.assertEquals(event.project_id, 1)
             self.assertEquals(event.datetime, date)
 
-    def test_url_filter(self):
-        event = Group.objects.from_kwargs(1, message='foo')
-        group = event.group
-        self.assertEquals(group.messagefiltervalue_set.filter(key='url').count(), 0)
-
-        event = Group.objects.from_kwargs(1, message='foo', **{
-            'sentry.interfaces.Http': {
-                'url': 'http://example.com',
-            }
-        })
-        group = event.group
-        self.assertEquals(group.messagefiltervalue_set.filter(key='url').count(), 1)
-        res = group.messagefiltervalue_set.filter(key='url').get()
-        self.assertEquals(res.value, 'http://example.com')
-        self.assertEquals(res.times_seen, 1)
-
-        event = Group.objects.from_kwargs(1, message='foo', **{
-            'sentry.interfaces.Http': {
-                'url': 'http://example.com',
-            }
-        })
-        group = event.group
-        self.assertEquals(group.messagefiltervalue_set.filter(key='url').count(), 1)
-        res = group.messagefiltervalue_set.filter(key='url').get()
-        self.assertEquals(res.value, 'http://example.com')
-        self.assertEquals(res.times_seen, 2)
-
-        event = Group.objects.from_kwargs(1, message='foo', **{
-            'sentry.interfaces.Http': {
-                'url': 'http://example.com/2',
-            }
-        })
-        group = event.group
-        self.assertEquals(group.messagefiltervalue_set.filter(key='url').count(), 2)
-        results = list(group.messagefiltervalue_set.filter(key='url').order_by('id'))
-        res = results[0]
-        self.assertEquals(res.value, 'http://example.com')
-        self.assertEquals(res.times_seen, 2)
-        res = results[1]
-        self.assertEquals(res.value, 'http://example.com/2')
-        self.assertEquals(res.times_seen, 1)
-
     def test_site_filter(self):
         event = Group.objects.from_kwargs(1, message='foo')
         group = event.group
@@ -170,3 +130,34 @@ class SentryManagerTest(TestCase):
         # ensure that calling it again doesnt raise a db error
         Group.objects.from_kwargs(1, event_id=1, message='foo')
         self.assertEquals(Event.objects.count(), 1)
+
+    def test_does_update_messagecountbyminute(self):
+        event = Group.objects.from_kwargs(1, message='foo')
+        inst = MessageCountByMinute.objects.filter(group=event.group)
+        self.assertTrue(inst.exists())
+        inst = inst.get()
+        self.assertEquals(inst.times_seen, 1)
+
+        event = Group.objects.from_kwargs(1, message='foo')
+        inst = MessageCountByMinute.objects.get(group=event.group)
+        self.assertEquals(inst.times_seen, 2)
+
+    def test_does_update_projectcountbyminute(self):
+        event = Group.objects.from_kwargs(1, message='foo')
+        inst = ProjectCountByMinute.objects.filter(project=event.project)
+        self.assertTrue(inst.exists())
+        inst = inst.get()
+        self.assertEquals(inst.times_seen, 1)
+
+        event = Group.objects.from_kwargs(1, message='foo')
+        inst = ProjectCountByMinute.objects.get(project=event.project)
+        self.assertEquals(inst.times_seen, 2)
+
+    def test_updates_group(self):
+        Group.objects.from_kwargs(1, message='foo', checksum='a' * 32)
+        event = Group.objects.from_kwargs(1, message='foo', checksum='a' * 32)
+
+        group = Group.objects.get(pk=event.group_id)
+
+        self.assertEquals(group.times_seen, 2)
+        self.assertEquals(group.last_seen, event.datetime)
